summaryrefslogtreecommitdiffstats
path: root/kioslaves/imap4/rfcdecoder.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kioslaves/imap4/rfcdecoder.cc')
-rw-r--r--kioslaves/imap4/rfcdecoder.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/kioslaves/imap4/rfcdecoder.cc b/kioslaves/imap4/rfcdecoder.cc
index 426911d0..4eeb207d 100644
--- a/kioslaves/imap4/rfcdecoder.cc
+++ b/kioslaves/imap4/rfcdecoder.cc
@@ -154,7 +154,7 @@ TQString rfcDecoder::fromIMAP (const TQString & inSrc)
return TQString::fromUtf8 (dst.data ());
}
/* tqreplace " with \" and \ with \\ " and \ characters */
TQString rfcDecoder::quoteIMAP(const TQString &src)
{
uint len = src.length();
@@ -311,7 +311,7 @@ rfcDecoder::codecForName (const TQString & _str)
if (_str.isEmpty ())
return NULL;
return TQTextCodec::codecForName (_str.lower ().
- tqreplace ("windows", "cp").latin1 ());
+ replace ("windows", "cp").latin1 ());
}
//-----------------------------------------------------------------------------
@@ -338,7 +338,7 @@ rfcDecoder::decodeRFC2047String (const TQString & _str, TQString & charset,
TQString & language)
{
//do we have a rfc string
- if (_str.tqfind("=?") < 0)
+ if (_str.find("=?") < 0)
return _str;
TQCString aStr = _str.ascii (); // TQString.length() means Unicode chars
@@ -371,7 +371,7 @@ rfcDecoder::decodeRFC2047String (const TQString & _str, TQString & charset,
else
{
charset = TQCString (beg, i - 1); // -2 + 1 for the zero
- int pt = charset.tqfindRev('*');
+ int pt = charset.findRev('*');
if (pt != -1)
{
// save language for later usage
@@ -628,13 +628,13 @@ rfcDecoder::encodeRFC2231String (const TQString & _str)
const TQString
rfcDecoder::decodeRFC2231String (const TQString & _str)
{
- int p = _str.tqfind ('\'');
+ int p = _str.find ('\'');
//see if it is an rfc string
if (p < 0)
return _str;
- int l = _str.tqfindRev ('\'');
+ int l = _str.findRev ('\'');
//second is language
if (p >= l)
@@ -154,7 +154,7 @@ TQString rfcDecoder::fromIMAP (const TQString & inSrc)
return TQString::fromUtf8 (dst.data ());
}
-/* tqreplace " with \" and \ with \\ " and \ characters */
+/* replace " with \" and \ with \\ " and \ characters */
TQString rfcDecoder::quoteIMAP(const TQString &src)
{